OC.L10N.register(
    "text",
    {
    "New text file" : "ახალი ტექსტ ფაილი",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "ატვირთული ფაილი აჭარბებს php.ini-ში დაყენებულ upload_max_filesize დირექტივას",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ატვირთული ფაილი აჭარბებს HTML ფორამაში მითითებულ MAX_FILE_SIZE დირექტივას",
    "No file was uploaded" : "ფაილი არ აიტვირთა",
    "Missing a temporary folder" : "დროებითი დირექტორია არ არსებობს",
    "Text" : "ტექსტი",
    "Translate" : "გადათარგმნეთ",
    "Guest" : "სტუმარი",
    "Offline" : "კავშირ-გარეშე რეჟიმი",
    "Saved" : "შენახულია",
    "Unsaved changes" : "შეუნახავი ცვლილებები",
    "Formatting help" : "დახმარება ფორმატირებაზე",
    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
    "Save changes" : "ცვილებების შენახვა",
    "Cancel" : "გაუქმება",
    "URL" : "URL",
    "Select language" : "აირჩიეთ ენა",
    "to" : "ვის",
    "Replace" : "ჩანაცვლება",
    "Source code" : "კოდი",
    "Undo" : "დაბრუნება",
    "Info" : "ინფორმაცია",
    "Success" : "წარმატება",
    "Warning" : "გაფრთხილება",
    "Edit" : "ცვლილება",
    "Unsupported image type" : "ამ სურათის სახეობა არაა მხარდაჭერილი"
},
"nplurals=2; plural=(n!=1);");
